package com.kakao.sdk.auth.network

import com.kakao.sdk.common.network.ApiFactory
import com.kakao.sdk.common.network.AppKeyInterceptor
import com.kakao.sdk.common.network.KakaoAgentInterceptor
import com.kakao.sdk.common.KakaoSdk
import com.kakao.sdk.common.Constants
import okhttp3.OkHttpClient

/**
 * 비RX 로그인기반 kapi.kakao.com 클라이언트 생성
 */
val ApiFactory.kapiWithOAuth by lazy {
    ApiFactory.withClientAndAdapter(
        "${Constants.SCHEME}://${KakaoSdk.serverHosts.kapi}",
        OkHttpClient.Builder()
            .authenticator(RefreshTokenAuthenticator())
            .addInterceptor(KakaoAgentInterceptor())
            .addInterceptor(AccessTokenInterceptor())
            .addInterceptor(DynamicAgreementInterceptor())
            .addInterceptor(ApiFactory.loggingInterceptor)
    )
}

/**
 * 비RX kauth.kakao.com 클라이언트 생성
 */
val ApiFactory.kauth by lazy {
    ApiFactory.withClientAndAdapter(
        "${Constants.SCHEME}://${KakaoSdk.serverHosts.kauth}",
        OkHttpClient.Builder()
            .addInterceptor(KakaoAgentInterceptor())
            .addInterceptor(AppKeyInterceptor())
            .addInterceptor(ApiFactory.loggingInterceptor)
    )
}
