package com.kakao.sdk.user

import com.kakao.sdk.common.json.IntDate
import com.kakao.sdk.user.model.AccessTokenInfo
import com.kakao.sdk.user.model.User
import com.kakao.sdk.user.model.UserServiceTerms
import com.kakao.sdk.user.model.UserShippingAddresses
import retrofit2.Call
import retrofit2.http.*
import java.util.*

/**
 * @author kevin.kang. Created on 2020-02-04..
 */
interface UserApi {
    @GET(Constants.V2_ME_PATH)
    fun me(
        @Query(Constants.SECURE_RESOURCE) secureResource: Boolean = true,
        @Query(Constants.PROPERTYKEYS) properties: String? = null
    ): Call<User>

    @GET(Constants.V1_ACCESS_TOKEN_INFO_PATH)
    fun accessTokenInfo(): Call<AccessTokenInfo>

    @POST(Constants.V1_UPDATE_PROFILE_PATH)
    @FormUrlEncoded
    fun updateProfile(
        @Field(Constants.PROPERTIES) properties: Map<String, String>
    ): Call<Unit>

    @POST(Constants.V1_LOGOUT_PATH)
    fun logout(): Call<Unit>

    @POST(Constants.V1_UNLINK_PATH)
    fun unlink(): Call<Unit>

    @GET(Constants.V1_SHIPPING_ADDRESSES_PATH)
    fun shippingAddresses(
        @Query(Constants.ADDRESS_ID) addressId: Long? = null,
        @IntDate @Query(Constants.FROM_UPDATED_AT) fromUpdateAt: Date? = null,
        @Query(Constants.PAGE_SIZE) pageSize: Int? = null
    ): Call<UserShippingAddresses>

    /**
     * User 가 3rd의 동의항목에 동의한 내역을 반환한다.
     */
    @GET(Constants.V1_SERVICE_TERMS_PATH)
    fun serviceTerms(): Call<UserServiceTerms>
}